"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CoinspotPublicApi = void 0;
const axios_1 = __importDefault(require("axios"));
class CoinspotPublicApi {
    constructor() {
        this.BASE_URL = 'https://www.coinspot.com.au/pubapi/v2';
    }
    /**
     * Get latest prices for all coins
     * @returns {Promise<LatestPricesResponse>} Object containing latest prices for all coins
     */
    async getLatestPrices() {
        const response = await axios_1.default.get(`${this.BASE_URL}/latest`);
        return response.data;
    }
    /**
     * Get latest price for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<LatestCoinPricesResponse>} Object containing latest price for the specified coin
     */
    async getLatestCoinPrice(cointype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/latest/${cointype}`);
        return response.data;
    }
    /**
     * Get latest price for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<LatestCoinPricesResponse>} Object containing latest price for the specified coin in the specified market
     */
    async getLatestCoinMarketPrice(cointype, markettype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/latest/${cointype}/${markettype}`);
        return response.data;
    }
    /**
     * Get latest buy price for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<LatestBuySellPriceResponse>} Object containing latest buy price for the specified coin
     */
    async getLatestBuyPrice(cointype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/buyprice/${cointype}`);
        return response.data;
    }
    /**
     * Get latest buy price for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<LatestBuySellPriceResponse>} Object containing latest buy price for the specified coin in the specified market
     */
    async getLatestBuyMarketPrice(cointype, markettype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/buyprice/${cointype}/${markettype}`);
        return response.data;
    }
    /**
     * Get latest sell price for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<LatestBuySellPriceResponse>} Object containing latest sell price for the specified coin
     */
    async getLatestSellPrice(cointype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/sellprice/${cointype}`);
        return response.data;
    }
    /**
     * Get latest sell price for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<LatestBuySellPriceResponse>} Object containing latest sell price for the specified coin in the specified market
     */
    async getLatestSellMarketPrice(cointype, markettype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/sellprice/${cointype}/${markettype}`);
        return response.data;
    }
    /**
     * Get open orders for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<OpenOrdersResponse>} Object containing open buy and sell orders for the specified coin
     */
    async getOpenOrders(cointype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/orders/open/${cointype}`);
        return response.data;
    }
    /**
     * Get open orders for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<OpenOrdersResponse>} Object containing open buy and sell orders for the specified coin in the specified market
     */
    async getOpenMarketOrders(cointype, markettype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/orders/open/${cointype}/${markettype}`);
        return response.data;
    }
    /**
     * Get completed orders for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<CompletedOrdersResponse>} Object containing completed buy and sell orders for the specified coin
     */
    async getCompletedOrders(cointype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/orders/completed/${cointype}`);
        return response.data;
    }
    /**
     * Get completed orders for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<CompletedOrdersResponse>} Object containing completed buy and sell orders for the specified coin in the specified market
     */
    async getCompletedMarketOrders(cointype, markettype) {
        const response = await axios_1.default.get(`${this.BASE_URL}/orders/completed/${cointype}/${markettype}`);
        return response.data;
    }
}
exports.CoinspotPublicApi = CoinspotPublicApi;
//# sourceMappingURL=coinspotPublicApi.js.map