"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CoinspotReadOnlyApi = void 0;
const coinspotApiBase_1 = require("./coinspotApiBase");
class CoinspotReadOnlyApi extends coinspotApiBase_1.CoinspotApiBase {
    /**
     * Check the status of the API
     * @returns {Promise<ReadOnlyApiStatusResponse>} Object containing API status
     */
    async checkReadOnlyApiStatus() {
        return this.request('/status', {}, true);
    }
    /**
     * Get open market orders
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} [markettype] - Market coin short name (e.g., 'AUD', 'USDT')
     * @returns {Promise<OpenOrdersResponse>} Object containing open market orders for the specified coin and market
     */
    async getOpenMarketOrders(cointype, markettype) {
        return this.request('/orders/market/open', { cointype, markettype }, true);
    }
    /**
     * Get completed market orders
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} [markettype] - Market coin short name (e.g., 'AUD', 'USDT')
     * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format or UNIX EPOCH time
     * @param {string} [enddate] - End date in 'YYYY-MM-DD' format or UNIX EPOCH time
     * @param {number} [limit=200] - Number of records to return (max 500)
     * @returns {Promise<CompletedOrdersResponse>} Object containing completed market orders for the specified parameters
     */
    async getCompletedMarketOrders(cointype, markettype, startdate, enddate, limit) {
        return this.request('/orders/market/completed', { cointype, markettype, startdate, enddate, limit }, true);
    }
    /**
    * Get user's coin balances
    * @returns {Promise<MyCoinBalancesResponse>} Object containing user's coin balances
    */
    async getMyCoinBalances() {
        return this.request('/my/balances', {}, true);
    }
    /**
    * Get user's coin balance (available)
    * @param {string} cointype - Coin short name (e.g., 'AUD', 'BTC', 'LTC', 'DOGE')
    * @param {string} available - Whether to return available balance ('yes' or 'no')
    * @returns {Promise<MyCoinBalanceResponse>} Object containing user's coin balance
    */
    async getMyCoinBalance(cointype, available) {
        return this.request(`/my/balance/${cointype}?available=${available}`, {}, true);
    }
    /**
    * Get user's open market orders
    * @param {string} [cointype] - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} [markettype] - Market coin short name (e.g., 'USDT', 'AUD')
    * @returns {Promise<MyOpenMarketOrdersResponse>} Object containing user's open market orders
    */
    async getMyOpenMarketOrders(cointype, markettype) {
        return this.request('/my/orders/market/open', { cointype, markettype }, true);
    }
    /**
    * Get user's open limit orders
    * @param {string} [cointype] - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @returns {Promise<MyOpenLimitOrdersResponse>} Object containing user's open limit orders
    */
    async getMyOpenLimitOrders(cointype) {
        return this.request('/my/orders/limit/open', { cointype }, true);
    }
    /**
    * Get user's order history
    * @param {string} [cointype] - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} [markettype] - Market coin short name (e.g., 'AUD', 'USDT')
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format or UNIX EPOCH time
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format or UNIX EPOCH time
    * @param {number} [limit=200] - Number of records to return (max 500)
    * @returns {Promise<MyOrderHistoryResponse>} Object containing user's order history
    */
    async getMyOrderHistory(cointype, markettype, startdate, enddate, limit) {
        return this.request('/my/orders/completed', { cointype, markettype, startdate, enddate, limit }, true);
    }
    /**
    * Get user's market order history
    * @param {string} [cointype] - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} [markettype] - Market coin short name (e.g., 'AUD', 'USDT')
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format or UNIX EPOCH time
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format or UNIX EPOCH time
    * @param {number} [limit=200] - Number of records to return (max 500)
    * @returns {Promise<MyOrderHistoryResponse>} Object containing user's market order history
    */
    async getMyMarketOrderHistory(cointype, markettype, startdate, enddate, limit) {
        return this.request('/my/orders/market/completed', { cointype, markettype, startdate, enddate, limit }, true);
    }
    /**
    * Get user's send and receive history
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format
    * @returns {Promise<MySendReceiveHistoryResponse>} Object containing user's send and receive history
    */
    async getMySendReceiveHistory(startdate, enddate) {
        return this.request('/my/sendreceive', { startdate, enddate }, true);
    }
    /**
    * Get user's deposit history
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format
    * @returns {Promise<MyDepositHistoryResponse>} Object containing user's deposit history
    */
    async getMyDepositHistory(startdate, enddate) {
        return this.request('/my/deposits', { startdate, enddate }, true);
    }
    /**
    * Get user's withdrawal history
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format
    * @returns {Promise<MyWithdrawalHistoryResponse>} Object containing user's withdrawal history
    */
    async getMyWithdrawalHistory(startdate, enddate) {
        return this.request('/my/withdrawals', { startdate, enddate }, true);
    }
    /**
    * Get user's affiliate payments
    * @returns {Promise<MyAffiliatePaymentsResponse>} Object containing user's affiliate payments
    */
    async getMyAffiliatePayments() {
        return this.request('/my/affiliatepayments', {}, true);
    }
    /**
    * Get user's referral payments
    * @returns {Promise<MyReferralPaymentsResponse>} Object containing user's referral payments
    */
    async getMyReferralPayments() {
        return this.request('/my/referralpayments', {}, true);
    }
}
exports.CoinspotReadOnlyApi = CoinspotReadOnlyApi;
//# sourceMappingURL=coinspotReadOnlyApi.js.map